@@ -3,10 +3,10 @@
 """
 BGE 开放平台 SDK 客户端模块。
 
-当前模块提供了两个主要的类 OAuth2 和 API，他们分别提供了对 BGE 开放平台的 OAuth2 相关
+当前模块提供了两个主要的类 OAuth2 和 API,他们分别提供了对 BGE 开放平台的 OAuth2 相关
 接口和其他接口的调用方法。
 
-使用示例：
+使用示例:
 
     >>> oauth2 = OAuth2(
             'demo', 'demo', endpoint='https://api.bge.genomics.cn')
@@ -25,7 +25,7 @@ from .utils import new_logger, human_byte
 
 from aliyunsdkcore.auth.credentials import StsTokenCredential
 from aliyunsdkcore.client import AcsClient
-from posixpath import split, join, isdir
+from posixpath import split, join, isdir, isfile
 from requests_toolbelt.multipart import encoder
 from six import text_type
 from six.moves.urllib.parse import urljoin, urlencode
@@ -46,7 +46,7 @@ ACCESS_TOKEN_API = '/oauth2/access_token'
 
 def progress_callback(bytes_consumed, total_bytes):
     sys.stdout.write(
-        '\r文件大小：{}, 上传进度: {}%，已上传 {}'.format(
+        '\r文件大小: {}, 上传进度: {}%, 已上传 {}'.format(
             human_byte(total_bytes, 2),
             '%.2f' % ((bytes_consumed / total_bytes) * 100),
             human_byte(bytes_consumed, 2)
@@ -58,7 +58,7 @@ def alive(self):
     """检查服务可用性
 
     Returns:
-        布尔型: True 代表可用，False 代表不可用
+        布尔型: True 代表可用, False 代表不可用
     """
     timeout = self.timeout
     verbose = self.verbose
@@ -75,16 +75,16 @@ def alive(self):
 class OAuth2(object):
     """OAuth2 授权客户端类。
     
-    管理关于 OAuth2 相关接口的调用，包括获取授权页面地址、授权码交换访问令牌等；
+    管理关于 OAuth2 相关接口的调用,包括获取授权页面地址、授权码交换访问令牌等;
     
     Args:
-        client_id (字符串): 第三方客户端 client_id；
-        client_secret (字符串): 第三方客户端 client_secret；
-        endpoint (字符串, 非必填): 平台对外服务的访问域名，
-                                 默认值为 https://api.bge.genomics.cn；
-        max_retries (数字, 非必填): 接口请求重试次数，默认值为 3；
-        timeout (数字, 非必填): 接口请求默认超时间，默认值为 None；
-        verbose (布尔, 非必填)：输出测试日志，默认值为 False；
+        client_id (字符串): 第三方客户端 client_id;
+        client_secret (字符串): 第三方客户端 client_secret;
+        endpoint (字符串, 非必填): 平台对外服务的访问域名,
+                                 默认值为 https://api.bge.genomics.cn;
+        max_retries (数字, 非必填): 接口请求重试次数,默认值为 3;
+        timeout (数字, 非必填): 接口请求默认超时间,默认值为 None;
+        verbose (布尔, 非必填): 输出测试日志,默认值为 False;
     """
 
     alive = alive
@@ -109,13 +109,13 @@ class OAuth2(object):
         """获取用户授权页链接地址。
 
         Args:
-            redirect_uri (str): 回调地址；
-            state (str, 非必填): 第三方自定义信息，返回授权码时原样返回，
-                                默认值为 None；
-            scopes (list, 非必填): 权限范围，支持多个。默认值为 None；
+            redirect_uri (str): 回调地址;
+            state (str, 非必填): 第三方自定义信息,返回授权码时原样返回,
+                                默认值为 None;
+            scopes (list, 非必填): 权限范围,支持多个。默认值为 None;
 
         Returns:
-            str: 用户授权页面地址；
+            str: 用户授权页面地址;
         """
         params = {
             "client_id": self.client_id,
@@ -133,12 +133,12 @@ class OAuth2(object):
         """用户授权码交换访问令牌
 
         Args:
-            code (str): 用户授权后平台返回的授权码；
-            redirect_uri (str): 回调地址；
+            code (str): 用户授权后平台返回的授权码;
+            redirect_uri (str): 回调地址;
 
         Returns:
-            AuthorizationCodeToken: 与授权用户关联的访问令牌，同时包含有刷新令牌、
-                                    过期时间等信息；
+            AuthorizationCodeToken: 与授权用户关联的访问令牌,同时包含有刷新令牌、
+                                    过期时间等信息;
         """
         data = {
             'client_id': self.client_id,
@@ -160,10 +160,10 @@ class OAuth2(object):
         """刷新令牌 access_token
 
         Args:
-            refresh_token (str): 授权码模式所获得的 refresh_token；
+            refresh_token (str): 授权码模式所获得的 refresh_token;
 
         Returns:
-            Model: 新的令牌数据；
+            Model: 新的令牌数据;
         """
         data = {
             'client_id': self.client_id,
@@ -184,7 +184,7 @@ class OAuth2(object):
         """客户端授权模式下获取访问令牌
 
         Returns:
-            Model: 访问令牌，包含 access_token、过期时间等；
+            Model: 访问令牌,包含 access_token、过期时间等;
         """
         data = {
             'client_id': self.client_id,
@@ -204,10 +204,10 @@ class OAuth2(object):
         """获取平台 API 调用客户端对象
 
         Args:
-            access_token (str): 访问令牌；
+            access_token (str): 访问令牌;
 
         Returns:
-            API: API 对象；
+            API: API 对象;
         """
         return API(
             access_token,
@@ -221,11 +221,11 @@ class API(object):
     """BGE 开放平台接口调用客户端
 
     Args:
-        access_token (str): 访问令牌；
-        endpoint (字符串, 非必填): 平台对外服务的访问域名，默认值为 pro-main；
-        max_retries (数字, 非必填): 接口请求重试次数，默认值为 3；
-        timeout (数字, 非必填): 接口请求默认超时间，默认值为 18；
-        verbose (布尔, 非必填)：输出测试日志，默认值为 False；
+        access_token (str): 访问令牌;
+        endpoint (字符串, 非必填): 平台对外服务的访问域名,默认值为 pro-main;
+        max_retries (数字, 非必填): 接口请求重试次数,默认值为 3;
+        timeout (数字, 非必填): 接口请求默认超时间,默认值为 18;
+        verbose (布尔, 非必填): 输出测试日志,默认值为 False;
     """
 
     alive = alive
@@ -250,7 +250,7 @@ class API(object):
         """验证当前使用的 access_token 有效性
 
         Returns:
-            Model: Token 元数据；
+            Model: Token 元数据;
         """
         timeout = self.timeout
         verbose = self.verbose
@@ -267,7 +267,7 @@ class API(object):
         """获取用户信息
 
         Returns:
-            Model: 用户数据；
+            Model: 用户数据;
         """
         timeout = self.timeout
         verbose = self.verbose
@@ -282,12 +282,12 @@ class API(object):
         """根据rsid查询变异位点信息
 
         Args:
-            biosample_id (str): 生物样品编号；
-            rsids (str): 多个 rs 编号，逗号分割（必填）；如：rs1229984；
-                         最多一次提供100个；
+            biosample_id (str): 生物样品编号;
+            rsids (str): 多个 rs 编号,逗号分割(必填);如: rs1229984;
+                         最多一次提供100个;
 
         Returns:
-            list: 变异位点信息；
+            list: 变异位点信息;
         """
         if biosample_id:
             biosample_id = biosample_id.upper()
@@ -314,10 +314,10 @@ class API(object):
         regions 与 bed_file 须且提供其中之一
         
         Args:
-            biosample_id(str): 生物样品编号；
-            only_variant_site(bool): 是否仅输出变异位置，默认为True；
-            regions(list): 需要抽取区域的坐标数据，数组长度不得超过5000；
-            bed_file(str): 需要抽取区域的 bed 文件路径，文件须为 zip 压缩文件
+            biosample_id(str): 生物样品编号;
+            only_variant_site(bool): 是否仅输出变异位置,默认为True;
+            regions(list): 需要抽取区域的坐标数据,数组长度不得超过5000;
+            bed_file(str): 需要抽取区域的 bed 文件路径,文件须为 zip 压缩文件
                            且内容不得超过 100w 行
         """
         timeout = self.timeout
@@ -358,22 +358,22 @@ class API(object):
                     **kwargs):
         """获取样品列表
 
-        授权码模式: 可通过本接口获取授权用户的样品；
-        客户端模式: 可通过本接口获取客户端应用通过注册接口注册(或预先生成)的样品；
+        授权码模式: 可通过本接口获取授权用户的样品;
+        客户端模式: 可通过本接口获取客户端应用通过注册接口注册(或预先生成)的样品;
 
         Args:
-            biosample_ids (str, 非必填): 生物样品 id，逗号分割多个；
-            biosample_sites (str, 非必填): 采样部位，取值范围：1-15；
-            omics (str, 非必填): 所属组学，取值范围：1-2；
-            project_ids (str, 非必填): 所属项目，逗号分割多个；
-            organisms (str, 非必填): 样品生物体，取值范围：1-3；
-            data_availability (boolean, 非必填): 数据可用性；
-            statuses (str, 非必填): 数据状态，详情见 BGE 开放平台文档；
-            next_page (int, 非必填): 要获取的页码，默认值为 None；
-            limit (int, 非必填): 每页返回数量，默认值为 50；
+            biosample_ids (str, 非必填): 生物样品 id,逗号分割多个;
+            biosample_sites (str, 非必填): 采样部位,取值范围: 1-15;
+            omics (str, 非必填): 所属组学,取值范围: 1-2;
+            project_ids (str, 非必填): 所属项目,逗号分割多个;
+            organisms (str, 非必填): 样品生物体,取值范围: 1-3;
+            data_availability (boolean, 非必填): 数据可用性;
+            statuses (str, 非必填): 数据状态,详情见 BGE 开放平台文档;
+            next_page (int, 非必填): 要获取的页码,默认值为 None;
+            limit (int, 非必填): 每页返回数量,默认值为 50;
 
         Returns:
-            list: 样品列表；
+            list: 样品列表;
         """
         params = {}
         params.update(kwargs)
@@ -411,14 +411,14 @@ class API(object):
     def get_sample(self, biosample_id, require_files=None):
         """获取样品
 
-        授权码模式: 可通过本接口获取授权用户的样品；
-        客户端模式: 可通过本接口获取客户端应用通过注册接口注册(或预先生成)的样品；
+        授权码模式: 可通过本接口获取授权用户的样品;
+        客户端模式: 可通过本接口获取客户端应用通过注册接口注册(或预先生成)的样品;
 
         Args:
-            biosample_id (str): 生物样品编号；
+            biosample_id (str): 生物样品编号;
 
         Returns:
-            Model: 样品数据；
+            Model: 样品数据;
         """
         if biosample_id:
             biosample_id = biosample_id.upper()
@@ -434,18 +434,43 @@ class API(object):
         result = request.get(url, params=params, timeout=timeout)
         return models.Model(result)
 
+    def externals(self, project_id, biosample_site, external_ids):
+        """获取样品外部编号对应的 BGE 平台套件编号
+
+        Args:
+            external_sample_ids (str): 外部生物样品id(逗号分割多个);
+            biosample_site (int): 采样部位;
+            project_id (str): 项目编号;
+
+        Returns:
+            list: 编号对应数据;
+        """
+        url = '/samples/external_ids'
+        params = {}
+        params['external_ids'] = external_ids
+        params['biosample_site'] = biosample_site
+        params['project_id'] = project_id
+        timeout = self.timeout
+        verbose = self.verbose
+        max_retries = self.max_retries
+        request = HTTPRequest(
+            self.endpoint, max_retries=max_retries, verbose=verbose)
+        request.set_authorization(self.token_type, self.access_token)
+        result = request.get(url, params=params, timeout=timeout)
+        return [models.Model(item) for item in result]
+
     def register_sample(self, external_sample_id, biosample_site,
                         project_id, **kwargs):
         """注册样品
 
         Args:
-            external_sample_id (str): 外部生物样品id；
-            biosample_site (int):  采样部位；
-            project_id (str): 项目编号；
-            **kwargs: 其他非必填数据，例：library_id="HWJBAYTGAA170328-18"；
+            external_sample_id (str): 外部生物样品id;
+            biosample_site (int): 采样部位;
+            project_id (str): 项目编号;
+            **kwargs: 其他非必填数据,例: library_id="HWJBAYTGAA170328-18";
 
         Returns:
-            Model: 样品数据，包含生物样品编号；
+            Model: 样品数据,包含生物样品编号;
         """
         data = {}
         data.update(kwargs)
@@ -467,11 +492,11 @@ class API(object):
     def improve_sample(self, biosample_id, **kwargs):
         """补充样品中未被赋值的信息
 
-        已赋值数据无法变更，否则接口报错；
+        已赋值数据无法变更,否则接口报错;
 
         Args:
-            biosample_id (str): 生物样品编号；
-            **kwargs: 需要赋值的字段和值；
+            biosample_id (str): 生物样品编号;
+            **kwargs: 需要赋值的字段和值;
         """
         if not kwargs:
             # 无更新
@@ -495,13 +520,13 @@ class API(object):
         """获取类群丰度
 
         Args:
-            biosample_id (str): 生物样品编号；
-            taxon_ids ([str], 非必填): BGE 物种编号，多个以逗号分割；
-            next_page ([int], 非必填): 当前页码，默认值为 1，即首页；
-            limit (int, 非必填): [description]. 默认值为 50；
+            biosample_id (str): 生物样品编号;
+            taxon_ids ([str], 非必填): BGE 物种编号,多个以逗号分割;
+            next_page ([int], 非必填): 当前页码,默认值为 1,即首页;
+            limit (int, 非必填): [description]. 默认值为 50;
 
         Returns:
-            Model: 类群丰度数据详情；
+            Model: 类群丰度数据详情;
         """
         if biosample_id:
             biosample_id = biosample_id.upper()
@@ -523,7 +548,7 @@ class API(object):
         result, pagination = request.get(
             '/microbiome/taxon_abundance', params=params, timeout=timeout)
         # TODO: upgrade in the future
-        # 暂时特殊处理此接口，统一丰度数据的返回方式
+        # 暂时特殊处理此接口,统一丰度数据的返回方式
         ret = models.Model({})
         ret['count'] = count = pagination['count']
         next_page = pagination['page'] + 1
@@ -538,15 +563,15 @@ class API(object):
         """获取功能丰度
 
         Args:
-            biosample_id (str): 生物样品编号；
-            catalog (str): 目录标签，可选值为：go、ko、eggnog、pfam、kegg-pwy、
-                           kegg-mdl、level4ec、metacyc-rxn、metacyc-pwy；
-            ids (str, 非必填): BGE物种功能编号，多个值以逗号隔开；
-            limit (int, 非必填): 一页返回数量，默认值为 50；
-            next_page (str, 非必填): 下一页，用于获取下一页数据；
+            biosample_id (str): 生物样品编号;
+            catalog (str): 目录标签,可选值为: go、ko、eggnog、pfam、kegg-pwy、
+                           kegg-mdl、level4ec、metacyc-rxn、metacyc-pwy;
+            ids (str, 非必填): BGE物种功能编号,多个值以逗号隔开;
+            limit (int, 非必填): 一页返回数量,默认值为 50;
+            next_page (str, 非必填): 下一页,用于获取下一页数据;
 
         Returns:
-            Model: 功能丰度数据详情；
+            Model: 功能丰度数据详情;
         """
         if biosample_id:
             biosample_id = biosample_id.upper()
@@ -574,16 +599,16 @@ class API(object):
         """获取基因丰度
 
         Args:
-            biosample_id (str): 生物样品编号；
-            catalog (str): 分类标签，可选值：IGC_9.9M、UniRef90_HUMAnN2_0.11；
-            data_type (str): 返回数据类型，可选值：list、file；
-            ids (str, 非必填): BGE 物种 IGC 基因编号，多个值以逗号分割，
-                                    如：igc_50,igc_51；
-            limit (int, 非必填): 一页最大返回数量，默认 50，最大值为 1000；
-            next_page (str, 非必填): 接口返回的下一页参数；
+            biosample_id (str): 生物样品编号;
+            catalog (str): 分类标签,可选值: IGC_9.9M、UniRef90_HUMAnN2_0.11;
+            data_type (str): 返回数据类型,可选值: list、file;
+            ids (str, 非必填): BGE 物种 IGC 基因编号,多个值以逗号分割,
+                                    如: igc_50,igc_51;
+            limit (int, 非必填): 一页最大返回数量,默认 50,最大值为 1000;
+            next_page (str, 非必填): 接口返回的下一页参数;
 
         Returns:
-            Model: 基因丰度数据详情；
+            Model: 基因丰度数据详情;
         """
         if biosample_id:
             biosample_id = biosample_id.upper()
@@ -610,10 +635,10 @@ class API(object):
     def get_upload_token(self, **kwargs):
         """获取文件上传授权
         
-        获取的授权仅包括当前目录（不含子目录）下的文件读、写权限；
+        获取的授权仅包括当前目录(不含子目录)下的文件读、写权限;
 
         Returns:
-            Model: 授权数据；
+            Model: 授权数据;
         """
         timeout = self.timeout
         verbose = self.verbose
@@ -624,29 +649,48 @@ class API(object):
         result = request.post('/sts/token', data=kwargs, timeout=timeout)
         return models.Model(result)
 
-    def upload(self, filename, file_or_string, cmk_id=None):
+    def upload(self, filename, file_or_string, part_size=None,
+               multipart_threshold=None, multipart_num_threads=None,
+               cmk_id=None):
         """上传文件
 
         Args:
-            filename (str): 要上传到服务器的文件名；
-            file_or_string (file-like-object or str): 文件内容或类文件对象；
-            cmk_id (str)： 阿里云 KMS 服务用户主密钥 ID，加密上传时提供 CMK ID 即可；
+            filename (str): 要上传到服务器的文件名;
+            file_or_string (file-like-object or str): 文件内容或类文件对象;
+            part_size(num): 单个分片大小, 默认 50MB;
+            multipart_threshold(num): 上传数据大于或等于该值时分片上传, 默认 100M;
+            multipart_num_threads: 分片上传缺省线程数, 默认 4;
+            cmk_id (str): 阿里云 KMS 服务用户主密钥 ID,加密上传时提供 CMK ID 即可;
+                          提供 cmk_id 后不支持分片上传;
 
         Returns:
-            object_name: 文件的 OSS 对象名；
+            object_name: 文件的 OSS 对象名;
         """
         token = self.get_upload_token()
-        return self._upload_file(token, filename, file_or_string, cmk_id=cmk_id)
+        return self._upload(
+            token,
+            filename,
+            file_or_string,
+            part_size=part_size,
+            multipart_threshold=multipart_threshold,
+            multipart_num_threads=multipart_num_threads,
+            cmk_id=cmk_id,
+        )
 
-    def batch_upload(self, files, cmk_id=None):
+    def batch_upload(self, files, part_size=None,
+                     multipart_threshold=None, multipart_num_threads=None,
+                     cmk_id=None):
         """批量上传文件
 
         Args:
-            files (FileItem object list): 要上传到服务器的文件列表；
-            cmk_id (str)： 阿里云 KMS 服务用户主密钥 ID，加密上传时提供 CMK ID 即可；
+            files (FileItem object list): 要上传到服务器的文件列表;
+            part_size(num): 单个分片大小, 默认 50MB;
+            multipart_threshold(num): 上传数据大于或等于该值时分片上传, 默认 100M;
+            multipart_num_threads: 分片上传缺省线程数, 默认 4;
+            cmk_id (str): 阿里云 KMS 服务用户主密钥 ID,加密上传时提供 CMK ID 即可;
 
         Returns:
-            object_name: 文件的 OSS 对象名；
+            object_name: 文件的 OSS 对象名;
         """
         if not files:
             raise BGEError('files is required')
@@ -659,25 +703,37 @@ class API(object):
                 continue
             filename = file_obj.filename
             file_or_string = file_obj.file_or_string
-            sys.stdout.write('开始上传：{}\n'.format(filename))
-            object_name = self._upload_file(
-                token, filename, file_or_string, cmk_id=cmk_id)
+            sys.stdout.write('开始上传: {}\n'.format(filename))
+            object_name = self._upload(
+                token,
+                filename,
+                file_or_string,
+                part_size=part_size,
+                multipart_threshold=multipart_threshold,
+                multipart_num_threads=multipart_num_threads,
+                cmk_id=cmk_id
+            )
             sys.stdout.write('\n\n')
             sys.stdout.flush()
             object_names.append(object_name)
         return object_names
 
-    def upload_dir(self, dirpath, cmk_id=None):
+    def upload_dir(self, dirpath, part_size=None,
+                   multipart_threshold=None, multipart_num_threads=None,
+                   cmk_id=None):
         """上传目录下的文件(不递归上传子文件夹中文件)
 
-        仅上传目录中的文件，软链接、符号链接、文件夹均不会上传至平台。
+        仅上传目录中的文件,软链接、符号链接、文件夹均不会上传至平台。
 
         Args:
-            dirpath (str): 要上传到服务器的文件夹；
-            cmk_id (str)： 阿里云 KMS 服务用户主密钥 ID，加密上传时提供 CMK ID 即可；
+            dirpath (str): 要上传到服务器的文件夹;
+            part_size(num): 单个分片大小, 默认 50MB;
+            multipart_threshold(num): 上传数据大于或等于该值时分片上传, 默认 100M;
+            multipart_num_threads: 分片上传缺省线程数, 默认 4;
+            cmk_id (str): 阿里云 KMS 服务用户主密钥 ID,加密上传时提供 CMK ID 即可;
 
         Returns:
-            object_names: 上传的文件 OSS 对象名列表；
+            object_names: 上传的文件 OSS 对象名列表;
         """
         token = self.get_upload_token()
         object_names = []
@@ -685,16 +741,30 @@ class API(object):
             filepath = join(dirpath, filename)
             if isdir(filepath):
                 continue
-            sys.stdout.write('开始上传：{}\n'.format(filepath))
-            with open(filepath, 'rb') as fp:
-                object_name = self._upload_file(
-                    token, filename, fp, cmk_id=cmk_id)
+            sys.stdout.write('开始上传: {}\n'.format(filepath))
+            object_name = self._upload(
+                token,
+                filename,
+                filepath,
+                part_size=part_size,
+                multipart_threshold=multipart_threshold,
+                multipart_num_threads=multipart_num_threads,
+                cmk_id=cmk_id
+            )
             sys.stdout.write('\n\n')
             sys.stdout.flush()
             object_names.append(object_name)
         return object_names
 
-    def _upload_file(self, token, filename, file_or_string, cmk_id=None):
+    def _upload(self, token, filename, file_or_string, part_size=None,
+                multipart_threshold=None, multipart_num_threads=None,
+                cmk_id=None):
+        if part_size is None:
+            part_size = constants.PART_SIZE
+        if multipart_threshold is None:
+            multipart_threshold = constants.MULTIPART_THRESHOLD
+        if multipart_num_threads is None:
+            multipart_num_threads = constants.MULTIPART_NUM_THREADS
         token_meta = self.introspect()
         if token_meta['active'] == False:
             raise BGEError('access_token has expired')
@@ -712,7 +782,7 @@ class API(object):
             region_id = token.region_id
             kms_provider = oss2.AliKMSProvider(
                 access_key_id, access_key_secret, region_id, cmk_id)
-            # NOTE 官方 oss2 处理 STS 加密上传存在 bug，等待其修复，此处做代码动态修改
+            # NOTE 官方 oss2 处理 STS 加密上传存在 bug,等待其修复,此处做代码动态修改
             sts_token_credential = StsTokenCredential(
                 access_key_id, access_key_secret, security_token)
             kms_provider.kms_client = AcsClient(
@@ -724,26 +794,41 @@ class API(object):
         object_name = '%s/%s' % (destination, filename)
         bge_open_client_id_header = 'x-oss-meta-bge-open-client-id'
         custom_headers = { bge_open_client_id_header: client_id }
-        bucket.put_object(
-            object_name,
-            file_or_string,
-            headers=custom_headers,
-            progress_callback=progress_callback)
-        sys.stdout.write('')
+        if isinstance(file_or_string, str) and isfile(file_or_string):
+            # 分片上传仅支持文件路径，不支持文件对象
+            oss2.resumable_upload(
+                bucket,
+                object_name,
+                file_or_string,
+                progress_callback=progress_callback,
+                headers=custom_headers,
+                part_size=part_size,
+                num_threads=multipart_num_threads,
+                multipart_threshold=multipart_threshold
+            )
+        else:
+            bucket.put_object(
+                object_name,
+                file_or_string,
+                headers=custom_headers,
+                progress_callback=progress_callback
+            )
+        sys.stdout.write('\n')
+        sys.stdout.flush()
         return object_name
 
     def get_download_url(self, object_name, region=None,
                          expiration_time=600, **kwargs):
-        """获取阿里云OSS（对象存储）中的文件下载地址
+        """获取阿里云OSS(对象存储)中的文件下载地址
 
         Args:
-            object_name (str): OSS对象；
-            region (str, 非必填): 区域（domestic、international），默认值为
-                                 domestic；
-            expiration_time (int, 非必填): 下载地址过期时间，默认值 600s；
+            object_name (str): OSS对象;
+            region (str, 非必填): 区域(domestic、international),默认值为
+                                 domestic;
+            expiration_time (int, 非必填): 下载地址过期时间,默认值 600s;
 
         Returns:
-            Model: 文件下载地址；
+            Model: 文件下载地址;
         """
         data = {}
         data.update(kwargs)
@@ -763,15 +848,15 @@ class API(object):
 
     def download(self, object_name, fp, region=None,
                  expiration_time=600, chunk_size=8192, **kwargs):
-        """下载存储在阿里云OSS（对象存储）中的文件
+        """下载存储在阿里云OSS(对象存储)中的文件
 
         Args:
-            object_name (str): OSS对象；
-            fp(file like object): 可写的类文件对象；
-            region (str, 非必填): 区域（domestic、international），默认值为
-                                 domestic；
+            object_name (str): OSS对象;
+            fp(file like object): 可写的类文件对象;
+            region (str, 非必填): 区域(domestic、international),默认值为
+                                 domestic;
             chunk_size(int): 下载块大小
-            expiration_time (int, 非必填): 下载地址过期时间，默认值 600s；
+            expiration_time (int, 非必填): 下载地址过期时间,默认值 600s;
         """
         inst = self.get_download_url(
             object_name, region=None, expiration_time=expiration_time,
@@ -808,17 +893,17 @@ class API(object):
     def aggregate_omics_data(self, data_element_id, time_dimension, start_time,
                              end_time=None, biosample_id=None,
                              interval=1, periods=100, **kwargs):
-        """聚合组学数据（目前仅支持聚合数据流中符合平台设定 JSONPath 规则的数值型数据）
+        """聚合组学数据(目前仅支持聚合数据流中符合平台设定 JSONPath 规则的数值型数据)
 
         Args:
-            data_element_id (str, 必填): 数据元编号；
-            time_dimension (str, 必填): 子聚合的时间维度，可选值：year, quarter,
+            data_element_id (str, 必填): 数据元编号;
+            time_dimension (str, 必填): 子聚合的时间维度,可选值: year, quarter,
                                         month, week, day, minute, second
-            start_time (str, 必填): 数据流生成时间的起始时间；
-            end_time (str, 非必填): 数据流生成时间的结束时间，为空时默认取当前时间；
-            biosample_id (str, 非必填): 生物样品编号，客户端模式下为必填；
-            interval (int, 非必填): 聚合时间维度间隔，默认:1
-            periods (int, 非必填): 聚合时间维度返回数，默认:100，最大值：100
+            start_time (str, 必填): 数据流生成时间的起始时间;
+            end_time (str, 非必填): 数据流生成时间的结束时间,为空时默认取当前时间;
+            biosample_id (str, 非必填): 生物样品编号,客户端模式下为必填;
+            interval (int, 非必填): 聚合时间维度间隔,默认:1
+            periods (int, 非必填): 聚合时间维度返回数,默认:100,最大值: 100
         
         Returns:
             Model: 返回的聚合数据
@@ -854,11 +939,11 @@ class API(object):
         
         
         Args:
-            biosample_id (str, 非必填): 生物样品编号，客户端模式下为必填；
+            biosample_id (str, 非必填): 生物样品编号,客户端模式下为必填;
             start_time (str, 非必填): 数据流生成时间的起始时间
             end_time (str, 非必填): 数据流生成时间的结束时间
-            sort_direction (str, 非必填): 排序方式，默认：desc
-            limit (int, 非必填): 每页返回数量，默认:100
+            sort_direction (str, 非必填): 排序方式,默认: desc
+            limit (int, 非必填): 每页返回数量,默认:100
             next_page (str, 非必填): 下一页参数
         
         Returns:
@@ -893,15 +978,15 @@ class API(object):
         """根据数据元编号或数据集编号获取数据项
 
         Args:
-            namespace（str）：命名空间
-            biosample_id (str): 生物样品编号；
-            collection_id（str，非必填）：数据集编号，与 data_element_ids 互斥；
-            data_element_ids (str，非必填): 多个数据元编号，逗号分割（必填）；
-                                           最多一次提供100个；
-            next_page (int，非必填): 下一页；
+            namespace(str): 命名空间
+            biosample_id (str): 生物样品编号;
+            collection_id(str,非必填): 数据集编号,与 data_element_ids 互斥;
+            data_element_ids (str,非必填): 多个数据元编号,逗号分割(必填);
+                                           最多一次提供100个;
+            next_page (int,非必填): 下一页;
 
         Returns:
-            Model: 返回的数据项数据；
+            Model: 返回的数据项数据;
         """
         if biosample_id:
             biosample_id = biosample_id.upper()
@@ -928,11 +1013,11 @@ class API(object):
         """模型调用
 
         Args:
-            model_id (str): 模型编号；
-            **kwargs: 模型相关参数，由模型定义的参数决定；
+            model_id (str): 模型编号;
+            **kwargs: 模型相关参数,由模型定义的参数决定;
 
         Returns:
-            Model: 任务id，时间和状态；
+            Model: 任务id,时间和状态;
         """
         params = {}
         params.update(kwargs)
@@ -955,11 +1040,11 @@ class API(object):
         """调用灰度部署版本模型
 
         Args:
-            model_id (str): 模型编号；
-            **kwargs: 模型相关参数，由模型定义的参数决定；
+            model_id (str): 模型编号;
+            **kwargs: 模型相关参数,由模型定义的参数决定;
 
         Returns:
-            Model: 任务id，时间和状态；
+            Model: 任务id,时间和状态;
         """
         params = {}
         params.update(kwargs)
@@ -985,12 +1070,12 @@ class API(object):
         Args:
             model_id (str): 模型编号。
             object_name (str): 模型源代码文件阿里云 OSS 对象路径。
-            runtime (str, optional): 运行环境版本。默认值：python3。
-            memory_size (int, optional): 内存占用量，单位：MB。默认：128MB。
-            timeout (int, 非必填): 模型运行超时时间，单位：秒。默认：900。
+            runtime (str, optional): 运行环境版本。默认值: python3。
+            memory_size (int, optional): 内存占用量,单位: MB。默认: 128MB。
+            timeout (int, 非必填): 模型运行超时时间,单位: 秒。默认: 900。
 
         Returns:
-            Model: 任务id，时间和状态；
+            Model: 任务id,时间和状态;
         """
         data = {}
         data.update(kwargs)
@@ -1069,8 +1154,8 @@ class API(object):
 
         Args:
             model_id (str): 模型编号。
-            limit (int): 每页返回数量，默认值为 10。
-            next_page (int): 下一页；
+            limit (int): 每页返回数量,默认值为 10。
+            next_page (int): 下一页;
 
         Returns:
             [list]: 模型历史版本列表
@@ -1097,7 +1182,7 @@ class API(object):
             expfs (path): 模型扩展文件集。
 
         Returns:
-            Model: 任务id、时间、状态和返回值；
+            Model: 任务id、时间、状态和返回值;
         """
         if isinstance(expfs, text_type):
             filename = split(expfs)[1]
@@ -1107,7 +1192,7 @@ class API(object):
             total_bytes = monitor.len
             bytes_consumed = monitor.bytes_read
             sys.stdout.write(
-                '\r文件大小：{}, 上传进度: {}%，已上传 {}'.format(
+                '\r文件大小: {}, 上传进度: {}%, 已上传 {}'.format(
                     human_byte(total_bytes, 2),
                     '%.2f' % ((bytes_consumed / total_bytes) * 100),
                     human_byte(bytes_consumed, 2)
@@ -1139,10 +1224,10 @@ class API(object):
 
         Args:
             model_id (str): 模型编号。
-            **kwargs: 模型相关参数，由模型定义的参数决定；
+            **kwargs: 模型相关参数,由模型定义的参数决定;
 
         Returns:
-            Model: 授权模型运行的对称加密相关参数；
+            Model: 授权模型运行的对称加密相关参数;
         """
         data = {}
         data['model_id'] = model_id
@@ -1167,7 +1252,7 @@ class API(object):
             task_id (str): 任务编号。
 
         Returns:
-            Model: 任务id、时间、状态和返回值；
+            Model: 任务id、时间、状态和返回值;
         """
         timeout = self.timeout
         verbose = self.verbose
@@ -1187,7 +1272,7 @@ class API(object):
             model_id (str): 模型编号。
             doc_content (list): 文档内容
         Returns:
-            Model_id: 模型编号；
+            Model_id: 模型编号;
             version: 文档版本号。
         """
         data = {}
